# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.3.0] - 2025-12-08

- Add bedmap data integration with xopr ([#38](https://github.com/englacial/xopr/pull/38)) by @espg
- Fix loading layer picks ([#36](https://github.com/englacial/xopr/pull/36)) by @thomasteisberg
- Add pdoc API documentation to docs build ([#40](https://github.com/englacial/xopr/pull/40)) by @espg
- Flight line coverage increased from: 1019353 km → 1035652 km ([#39](https://github.com/englacial/xopr/pull/39)) by @github-actions
- Flight line coverage increased from: 1008929 km → 1019353 km [Added UTIG 2017 Antarctic Season] ([#34](https://github.com/englacial/xopr/pull/34)) by @github-actions
- Code cleanup: Fix critical bug and reduce codebase by 1k+ lines ([#32](https://github.com/englacial/xopr/pull/32)) by @espg


## [0.2.1] - 2025-09-30

- Maps rewrite to support multi colors for campaigns ([#31](https://github.com/thomasteisberg/xopr/pull/31)) by @espg


## [0.2.0] - 2025-09-18

- API design cleanup ([#24](https://github.com/thomasteisberg/xopr/pull/24)) by @thomasteisberg
- Add map module with parquet visualization  ([#20](https://github.com/thomasteisberg/xopr/pull/20)) by @espg
- Crossover analysis notebook ([#21](https://github.com/thomasteisberg/xopr/pull/21)) by @thomasteisberg
- Stac module fixes, optimizations, and enhancements-- transition to yml based reproducible workflows ([#10](https://github.com/thomasteisberg/xopr/pull/10)) by @espg


## [0.1.5] - 2025-08-25

- Geometry fixes and unit tests for geometry, opr_access ([#3](https://github.com/thomasteisberg/xopr/pull/3)) by @thomasteisberg
- STAC logic updates and unit tests ([#4](https://github.com/thomasteisberg/xopr/pull/4)) by @espg
- Load full attributes from data product files ([#2](https://github.com/thomasteisberg/xopr/pull/2)) by @thomasteisberg


## [0.1.0] - (1979-01-01)

- First release
